#! python3  # noqa E265

# standard library
import unittest
from pathlib import Path, PosixPath

from gpf_entrepot_toolbelt.utils.gpf_logger import gpf_logger_script

# project
from gpf_common_point_cloud.enums.entwine_enums import EntwineDataType
from gpf_common_point_cloud.models.gpf_entwine_params import GpfEntwineParams

# 3rd party

logger = gpf_logger_script(verbosity=0, title="TestEntwineParams")


# ################################
# ########## Classes #############
# ################################


class TestEntwineParams(unittest.TestCase):
    """Test for entwine params functions"""

    def test_from_dict_ok(self):
        # Given
        expectedGpfEntwineParams: GpfEntwineParams = GpfEntwineParams()
        expectedGpfEntwineParams.output = Path("/output")
        expectedGpfEntwineParams.input = Path("/input")
        expectedGpfEntwineParams.dataType = EntwineDataType.LASZIP
        expectedGpfEntwineParams.span = 256
        expectedGpfEntwineParams.bounds = [10, 10, 10, 10]
        expectedGpfEntwineParams.absolute = True
        expectedGpfEntwineParams.noOriginId = True
        expectedGpfEntwineParams.scale = [1, 1, 1]
        expectedGpfEntwineParams.maxNodeSize = 2000
        expectedGpfEntwineParams.minNodeSize = 1000
        expectedGpfEntwineParams.laz_14 = True
        expectedGpfEntwineParams.limit = 4
        expectedGpfEntwineParams.threads = 3
        expectedGpfEntwineParams.deep = 2
        expectedGpfEntwineParams.tmp = Path("/tmp")

        # When
        result_params = GpfEntwineParams().from_dict(
            {
                "output": PosixPath("/output"),
                "input": PosixPath("/input"),
                "dataType": EntwineDataType.LASZIP,
                "span": 256,
                "bounds": [10, 10, 10, 10],
                "absolute": True,
                "noOriginId": True,
                "scale": [1, 1, 1],
                "maxNodeSize": 2000,
                "minNodeSize": 1000,
                "laz_14": True,
                "limit": 4,
                "threads": 3,
                "deep": 2,
                "tmp": PosixPath("/tmp"),
            }
        )

        # Then
        self.assertEqual(result_params.to_dict(), expectedGpfEntwineParams.to_dict())

    def test_to_dict_ok(self):
        # Given
        gpfEntwineParams: GpfEntwineParams = GpfEntwineParams()
        gpfEntwineParams.output = Path("/output")
        gpfEntwineParams.input = Path("/input")
        gpfEntwineParams.dataType = EntwineDataType.LASZIP
        gpfEntwineParams.span = 256
        gpfEntwineParams.bounds = [10, 10, 10, 10]
        gpfEntwineParams.absolute = True
        gpfEntwineParams.noOriginId = True
        gpfEntwineParams.scale = [1, 1, 1]
        gpfEntwineParams.maxNodeSize = 2000
        gpfEntwineParams.minNodeSize = 1000
        gpfEntwineParams.laz_14 = True
        gpfEntwineParams.limit = 4
        gpfEntwineParams.threads = 3
        gpfEntwineParams.deep = 2
        gpfEntwineParams.tmp = Path("/tmp")

        expected_dict: dict = {
            "output": PosixPath("/output"),
            "input": PosixPath("/input"),
            "dataType": EntwineDataType.LASZIP,
            "span": 256,
            "bounds": [10, 10, 10, 10],
            "absolute": True,
            "noOriginId": True,
            "scale": [1, 1, 1],
            "maxNodeSize": 2000,
            "minNodeSize": 1000,
            "laz_14": True,
            "limit": 4,
            "threads": 3,
            "deep": 2,
            "tmp": PosixPath("/tmp"),
        }

        # When
        result_dict = gpfEntwineParams.to_dict()

        # Then
        self.assertEqual(result_dict, expected_dict)


# ################################
# ####### Stand-alone run ########
# ################################
if __name__ == "__main__":
    unittest.main()
